@@ -38,10 +38,10 @@ OC.L10N.register(
     "Comment" : "Displegadenn",
     "Accept" : "Asantiñ",
     "Remove" : "Lemel",
-    "email" : "postel",
     "Today" : "Hiziv",
     "Yesterday" : "Dec'h",
     "Choose target folder" : "Dibab an teuliad moned",
+    "Favorites" : "Pennrolloù",
     "Important info" : "Titouroù pouezus",
     "Other" : "All",
     "Forward" : "War-raok",
@@ -64,6 +64,7 @@ OC.L10N.register(
     "Date" : "Deiz",
     "Tags" : "Klavioù",
     "Translate to" : "Treiñ e",
+    "Deleted" : "Dilamet",
     "Help" : "Skoazell",
     "Actions" : "Oberoù",
     "Edit" : "Embann",
@@ -77,9 +78,6 @@ OC.L10N.register(
     "Shares" : "Rannañ",
     "Account connected" : "Kont kenstaged",
     "All" : "Pep tra",
-    "Favorites" : "Pennrolloù",
-    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
-    "Accounts" : "Kontoù",
-    "Loading …" : "O Kargañ ..."
+    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
