@@ -3,7 +3,7 @@
 declare(strict_types=1);
 
 /**
- * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2019-2024 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
@@ -21,8 +21,11 @@ use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Output\OutputInterface;
 use function memory_get_peak_usage;
 
-class TrainAccount extends Command {
+final class TrainAccount extends Command {
 	public const ARGUMENT_ACCOUNT_ID = 'account-id';
+	public const ARGUMENT_SHUFFLE = 'shuffle';
+	public const ARGUMENT_DRY_RUN = 'dry-run';
+	public const ARGUMENT_FORCE = 'force';
 
 	private AccountService $accountService;
 	private ImportanceClassifier $classifier;
@@ -41,20 +44,30 @@ class TrainAccount extends Command {
 		$this->classificationSettingsService = $classificationSettingsService;
 	}
 
-	/**
-	 * @return void
-	 */
-	protected function configure() {
+	protected function configure(): void {
 		$this->setName('mail:account:train');
 		$this->setDescription('Train the classifier of new messages');
 		$this->addArgument(self::ARGUMENT_ACCOUNT_ID, InputArgument::REQUIRED);
+		$this->addOption(self::ARGUMENT_SHUFFLE, null, null, 'Shuffle data set before training');
+		$this->addOption(
+			self::ARGUMENT_DRY_RUN,
+			null,
+			null,
+			'Don\'t persist classifier after training'
+		);
+		$this->addOption(
+			self::ARGUMENT_FORCE,
+			null,
+			null,
+			'Train an estimator even if the classification is disabled by the user'
+		);
 	}
 
-	/**
-	 * @return int
-	 */
 	protected function execute(InputInterface $input, OutputInterface $output): int {
 		$accountId = (int)$input->getArgument(self::ARGUMENT_ACCOUNT_ID);
+		$shuffle = (bool)$input->getOption(self::ARGUMENT_SHUFFLE);
+		$dryRun = (bool)$input->getOption(self::ARGUMENT_DRY_RUN);
+		$force = (bool)$input->getOption(self::ARGUMENT_FORCE);
 
 		try {
 			$account = $this->accountService->findById($accountId);
@@ -62,7 +75,8 @@ class TrainAccount extends Command {
 			$output->writeln("<error>account $accountId does not exist</error>");
 			return 1;
 		}
-		if (!$this->classificationSettingsService->isClassificationEnabled($account->getUserId())) {
+
+		if (!$force && !$this->classificationSettingsService->isClassificationEnabled($account->getUserId())) {
 			$output->writeln("<info>classification is turned off for account $accountId</info>");
 			return 2;
 		}
@@ -71,9 +85,13 @@ class TrainAccount extends Command {
 			$this->logger,
 			$output
 		);
+
 		$this->classifier->train(
 			$account,
-			$consoleLogger
+			$consoleLogger,
+			null,
+			$shuffle,
+			!$dryRun
 		);
 
 		$mbs = (int)(memory_get_peak_usage() / 1024 / 1024);
