@@ -23,6 +23,7 @@ class Version0156Date20190828140357 extends SimpleMigrationStep {
 	 *
 	 * @return ISchemaWrapper
 	 */
+	#[\Override]
 	public function changeSchema(IOutput $output, Closure $schemaClosure, array $options) {
 		/** @var ISchemaWrapper $schema */
 		$schema = $schemaClosure();
@@ -39,7 +40,6 @@ class Version0156Date20190828140357 extends SimpleMigrationStep {
 		]);
 		$mailboxTable->addColumn('account_id', Types::INTEGER, [
 			'notnull' => true,
-			'length' => 4,
 		]);
 		$mailboxTable->addColumn('sync_token', Types::STRING, [
 			'notnull' => true,
@@ -55,11 +55,9 @@ class Version0156Date20190828140357 extends SimpleMigrationStep {
 		]);
 		$mailboxTable->addColumn('messages', Types::INTEGER, [
 			'notnull' => true,
-			'length' => 4,
 		]);
 		$mailboxTable->addColumn('unseen', Types::INTEGER, [
 			'notnull' => true,
-			'length' => 4,
 		]);
 		$mailboxTable->addColumn('selectable', Types::BOOLEAN, [
 			'notnull' => false,
