@@ -49,16 +49,19 @@ class Provider implements IProvider {
 		$this->urlGenerator = $urlGenerator;
 	}
 
+	#[\Override]
 	public function getId(): string {
 		return Application::APP_ID;
 	}
 
+	#[\Override]
 	public function getName(): string {
 		return $this->l10n->t('Mails');
 	}
 
+	#[\Override]
 	public function getOrder(string $route, array $routeParameters): int {
-		if (strpos($route, Application::APP_ID . '.') === 0) {
+		if (str_starts_with($route, Application::APP_ID . '.')) {
 			// Active app, prefer Mail results
 			return -1;
 		}
@@ -66,6 +69,7 @@ class Provider implements IProvider {
 		return 20;
 	}
 
+	#[\Override]
 	public function search(IUser $user, ISearchQuery $query): SearchResult {
 		return $this->searchByFilter($user, $query, $query->getTerm());
 	}
