@@ -141,18 +141,11 @@ class MailManager implements IMailManager {
 		return $this->mailboxMapper->findAll($account);
 	}
 
-	/**
-	 * @param Account $account
-	 * @param string $name
-	 *
-	 * @return Mailbox
-	 * @throws ServiceException
-	 */
 	#[\Override]
-	public function createMailbox(Account $account, string $name): Mailbox {
+	public function createMailbox(Account $account, string $name, array $specialUse = []): Mailbox {
 		$client = $this->imapClientFactory->getClient($account);
 		try {
-			$folder = $this->folderMapper->createFolder($client, $name);
+			$folder = $this->folderMapper->createFolder($client, $name, $specialUse);
 			$this->folderMapper->fetchFolderAcls([$folder], $client);
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
