@@ -28,6 +28,7 @@ use Horde_Smtp_Exception;
 use OCA\Mail\Account;
 use OCA\Mail\Address;
 use OCA\Mail\AddressList;
+use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Contracts\IMailTransmission;
 use OCA\Mail\Db\LocalMessage;
 use OCA\Mail\Db\Mailbox;
@@ -67,6 +68,7 @@ class MailTransmission implements IMailTransmission {
 		private PerformanceLogger $performanceLogger,
 		private AliasesService $aliasesService,
 		private TransmissionService $transmissionService,
+		private IMailManager $mailManager,
 	) {
 	}
 
@@ -155,7 +157,16 @@ class MailTransmission implements IMailTransmission {
 			$localMessage->setRaw($mail->getRaw(false));
 			$localMessage->setStatus(LocalMessage::STATUS_RAW);
 		} catch (Horde_Mime_Exception $e) {
-			$this->logger->error($e->getMessage(), ['exception' => $e]);
+			if ($e->getPrevious() instanceof Horde_Smtp_Exception) {
+				/** @var Horde_Smtp_Exception $previousException */
+				$previousException = $e->getPrevious();
+				$this->logger->error('SMTP error: ' . $e->getMessage(), [
+					'exception' => $e,
+					'smtpErrorCode' => $previousException->getSmtpCode(),
+				]);
+			} else {
+				$this->logger->error($e->getMessage(), ['exception' => $e]);
+			}
 			if (in_array($e->getCode(), self::RETRIABLE_CODES, true)) {
 				$localMessage->setStatus(LocalMessage::STATUS_SMPT_SEND_FAIL);
 				return;
@@ -231,12 +242,7 @@ class MailTransmission implements IMailTransmission {
 			$transport = new Horde_Mail_Transport_Null();
 			$mail->send($transport, false, false);
 			$perfLogger->step('create IMAP draft message');
-			// save the message in the drafts folder
-			$draftsMailboxId = $account->getMailAccount()->getDraftsMailboxId();
-			if ($draftsMailboxId === null) {
-				throw new ClientException('No drafts mailbox configured');
-			}
-			$draftsMailbox = $this->mailboxMapper->findById($draftsMailboxId);
+			$draftsMailbox = $this->findOrCreateDraftsMailbox($account);
 			$this->messageMapper->save(
 				$client,
 				$draftsMailbox,
@@ -258,6 +264,20 @@ class MailTransmission implements IMailTransmission {
 		$perfLogger->end();
 	}
 
+	private function findOrCreateDraftsMailbox(Account $account): Mailbox {
+		$draftsMailboxId = $account->getMailAccount()->getDraftsMailboxId();
+
+		if ($draftsMailboxId === null) {
+			return $this->mailManager->createMailbox(
+				$account,
+				'Drafts',
+				[Horde_Imap_Client::SPECIALUSE_DRAFTS]
+			);
+		}
+
+		return $this->mailboxMapper->findById($draftsMailboxId);
+	}
+
 	/**
 	 * @param NewMessageData $message
 	 * @param Message|null $previousDraft
